@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 7.12 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2022, Mark Calabretta
+  WCSLIB 8.2 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2023, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: lin.c,v 7.12 2022/09/09 04:57:58 mcalabre Exp $
+  $Id: lin.c,v 8.2.1.2 2023/11/29 07:36:19 mcalabre Exp mcalabre $
 *===========================================================================*/
 
 #include <math.h>
@@ -32,8 +32,6 @@
 #include "lin.h"
 #include "dis.h"
 
-const int LINSET = 137;
-
 // Map status return value to message.
 const char *lin_errmsg[] = {
   "Success",
@@ -54,6 +52,8 @@ const int lin_diserr[] = {
   LINERR_DEDISTORT		//  5: DISERR_DEDISTORT
 };
 
+static const int LINSET = 137;
+
 // Convenience macro for invoking wcserr_set().
 #define LIN_ERRMSG(status) WCSERR_SET(status), lin_errmsg[status]
 
