@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 7.4 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2021, Mark Calabretta
+  WCSLIB 8.2 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2023, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: spc.c,v 7.4 2021/01/31 02:24:51 mcalabre Exp $
+  $Id: spc.c,v 8.2.1.1 2023/11/16 10:05:57 mcalabre Exp mcalabre $
 *===========================================================================*/
 
 #include <math.h>
@@ -137,6 +137,31 @@ int spcfree(struct spcprm *spc)
 
 //----------------------------------------------------------------------------
 
+int spcsize(const struct spcprm *spc, int sizes[2])
+
+{
+  if (spc == 0x0) {
+    sizes[0] = sizes[1] = 0;
+    return SPCERR_SUCCESS;
+  }
+
+  // Base size, in bytes.
+  sizes[0] = sizeof(struct spcprm);
+
+  // Total size of allocated memory, in bytes.
+  sizes[1] = 0;
+
+  int exsizes[2];
+
+  // spcprm::err.
+  wcserr_size(spc->err, exsizes);
+  sizes[1] += exsizes[0] + exsizes[1];
+
+  return SPCERR_SUCCESS;
+}
+
+//----------------------------------------------------------------------------
+
 int spcprt(const struct spcprm *spc)
 
 {
@@ -549,9 +574,9 @@ int spcx2s(
   xp = x;
   specp = spec;
   statp = stat;
-  for (ix = 0; ix < nx; ix++, xp += sx, specp += sspec) {
+  for (ix = 0; ix < nx; ix++, xp += sx, specp += sspec, statp++) {
     *specp = spc->w[1] + (*xp)*spc->w[2];
-    *(statp++) = 0;
+    *statp = 0;
   }
 
   // If X is the grism parameter then convert it to wavelength.
@@ -650,9 +675,9 @@ int spcs2x(
     xp = x;
     specp = spec;
     statp = stat;
-    for (ispec = 0; ispec < nspec; ispec++, specp += sspec, xp += sx) {
+    for (ispec = 0; ispec < nspec; ispec++, specp += sspec, xp += sx, statp++) {
       *xp = *specp;
-      *(statp++) = 0;
+      *statp = 0;
     }
   }
 
@@ -693,8 +718,8 @@ int spcs2x(
   // Convert X-type spectral variable to intermediate world coordinate x.
   xp = x;
   statp = stat;
-  for (ispec = 0; ispec < nspec; ispec++, xp += sx) {
-    if (*(statp++)) continue;
+  for (ispec = 0; ispec < nspec; ispec++, xp += sx, statp++) {
+    if (*statp) continue;
 
     *xp -= spc->w[1];
     *xp /= spc->w[2];
