@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 7.12 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2022, Mark Calabretta
+  WCSLIB 8.2 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2023, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: tab.c,v 7.12 2022/09/09 04:57:58 mcalabre Exp $
+  $Id: tab.c,v 8.2.1.2 2023/11/29 07:39:44 mcalabre Exp mcalabre $
 *===========================================================================*/
 
 #include <math.h>
@@ -33,8 +33,6 @@
 #include "wcsutil.h"
 #include "tab.h"
 
-const int TABSET = 137;
-
 // Map status return value to message.
 const char *tab_errmsg[] = {
   "Success",
@@ -44,6 +42,8 @@ const char *tab_errmsg[] = {
   "One or more of the x coordinates were invalid",
   "One or more of the world coordinates were invalid"};
 
+static const int TABSET = 137;
+
 // Convenience macro for invoking wcserr_set().
 #define TAB_ERRMSG(status) WCSERR_SET(status), tab_errmsg[status]
 
