@@ -1,6 +1,6 @@
 /*============================================================================
-  PGSBOX 7.12 - draw curvilinear coordinate axes for PGPLOT.
-  Copyright (C) 1997-2022, Mark Calabretta
+  PGSBOX 8.2 - draw curvilinear coordinate axes for PGPLOT.
+  Copyright (C) 1997-2023, Mark Calabretta
 
   This file is part of PGSBOX.
 
@@ -19,16 +19,21 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: cpgtest.c,v 7.12 2022/09/09 04:57:58 mcalabre Exp $
+  $Id: cpgtest.c,v 8.2.1.1 2023/11/16 10:05:59 mcalabre Exp mcalabre $
 *=============================================================================
 *
 *   cpgtest
 *
 *---------------------------------------------------------------------------*/
 
+// Needed to get nanosleep() from time.h.
+#define _POSIX_C_SOURCE 199309L
+
 #include <math.h>
 #include <stdio.h>
 #include <string.h>
+#include <time.h>
+
 #include <cpgplot.h>
 
 #include <cpgsbox.h>
@@ -115,6 +120,9 @@ int main()
   struct wcsprm wcs;
   wcs.flag = -1;
 
+  // Allow 250ms to view the plot on fast machines.
+  struct timespec nano = {(time_t)0, 250000000L};
+
   //--------------------------------------------------------------------------
   // Longitude-velocity map; the y-axis is regularly spaced in frequency but
   // is to be labelled as a true relativistic velocity.
@@ -184,6 +192,7 @@ int main()
   // Draw the frame.
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //--------------------------------------------------------------------------
@@ -248,6 +257,7 @@ int main()
   // Draw the frame.
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
 
@@ -306,6 +316,7 @@ int main()
   // Draw the frame.
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //--------------------------------------------------------------------------
@@ -388,6 +399,7 @@ int main()
   // Draw the frame.
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //-------------------------------------------------------------------------
@@ -510,6 +522,7 @@ int main()
   cpgsci(1);
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //--------------------------------------------------------------------------
@@ -720,6 +733,7 @@ int main()
   cpgsci(1);
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //--------------------------------------------------------------------------
@@ -880,6 +894,7 @@ int main()
   cpgsci(1);
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //--------------------------------------------------------------------------
@@ -955,6 +970,7 @@ int main()
   // Draw the frame.
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //--------------------------------------------------------------------------
@@ -1039,6 +1055,7 @@ int main()
   // Draw the frame.
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //--------------------------------------------------------------------------
@@ -1116,6 +1133,7 @@ int main()
   // Draw the frame.
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //--------------------------------------------------------------------------
@@ -1239,6 +1257,7 @@ int main()
   // Draw the frame.
   cpgbox("bc", 0.0f, 0, "bc", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //--------------------------------------------------------------------------
@@ -1281,6 +1300,7 @@ int main()
   // Draw the frame.
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //--------------------------------------------------------------------------
@@ -1347,6 +1367,7 @@ int main()
   // Draw the frame.
   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+  nanosleep(&nano, 0x0);
   cpgpage();
 
   //--------------------------------------------------------------------------
